@@ -8,7 +8,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION          = '0.20';
+our $VERSION          = '0.22';
 our @CANNED_RESPONSES = ();
 
 use LWP::UserAgent;
@@ -105,6 +105,11 @@ sub intl_url {
         return $url;
     }
 
+    if ($self->{locale} eq "jp") {
+       $url =~ s/\.com/.co.jp/;
+       return $url;
+    }
+
     if($self->{locale} eq "uk" or
        $self->{locale} eq "de") {
         $url =~ s/xml/xml-eu/;
@@ -168,6 +173,10 @@ sub request {
             INFO("Page $page/$ref->{TotalPages}");
         }
 
+        if(exists $ref->{TotalResults}) {
+            $res->total_results( $ref->{TotalResults} );
+        }
+
         if(exists $ref->{ErrorMsg}) {
 
             if($AMZN_WISHLIST_BUG_ENCOUNTERED &&
@@ -220,6 +229,9 @@ sub request {
     }
 
     $res->status(1);
+    # We have a valid response, so if TotalResults isn't set, 
+    # we most likely have a single response
+    $res->total_results(1) unless defined $res->total_results();
     return $res;
 }
 
@@ -329,7 +341,12 @@ sub make_array_accessor {
                 }
             }
                # Return a list
-            return \@{\$self->{$name}};
+            if(exists \$self->{$name} and
+               ref \$self->{$name} eq "ARRAY") {
+                return \@{\$self->{$name}};
+            }
+
+            return undef;
         }
 EOT
 
@@ -523,9 +540,12 @@ Response objects always have the methods
 C<is_success()>,
 C<is_error()>,
 C<message()>,
+C<total_results()>,
 C<as_string()> and
 C<properties()> available.
 
+C<total_results()> returns the total number of results the search
+yielded.
 C<properties()> returns one or more C<Net::Amazon::Property> objects of type
 C<Net::Amazon::Property> (or one of its subclasses like
 C<Net::Amazon::Property::Book>, C<Net::Amazon::Property::Music>
@@ -538,7 +558,23 @@ in Amazon's database:
              $_->OurPrice(), "\n";
     }
 
-Also the specialized classes C<Net::Amazon::Property::Book> and
+Commonly available accessors are 
+C<OurPrice()>,
+C<ImageUrlLarge()>,
+C<ImageUrlMedium()>,
+C<ImageUrlSmall()>,
+C<ReleaseDate()>,
+C<Catalog()>,
+C<Asin()>,
+C<url()>,
+C<Manufacturer()>,
+C<UsedPrice()>,
+C<ListPrice()>,
+C<ProductName()>,
+C<Availability()>.
+For details, check L<Net::Amazon::Property>.
+
+Also, the specialized classes C<Net::Amazon::Property::Book> and
 C<Net::Amazon::Property::Music> feature convenience methods like
 C<authors()> (returning the list of authors of a book) or 
 C<album()> for CDs, returning the album title.
@@ -969,6 +1005,18 @@ and on CPAN.
 
 =head1 SEE ALSO
 
+The following modules play well within the C<Net::Amazon> framework:
+
+=over 4
+
+=item C<Net::Amazon::RemoteCart>
+
+by David Emery E<lt>dave@skiddlydee.comE<gt> provides a complete API for
+creating Amazon shopping carts on a local site, managing them and finally 
+submitting them to Amazon for checkout. It is available on CPAN.
+
+=back
+
 =head1 CONTACT
 
 The C<Net::Amazon> project's home page is hosted on 
@@ -988,6 +1036,7 @@ Mike Schilli, E<lt>na@perlmeister.comE<gt> (Please contact me via the mailing li
 Contributors (thanks y'all!):
 
     Barnaby Claydon <bclaydon@perseus.com>
+    Batara Kesuma <bkesuma@gaijinweb.com>
     Bill Fitzpatrick
     Brian Hirt <bhirt@mobygames.com>
     Dan Sully <daniel@electricrain.com>
@@ -999,6 +1048,7 @@ Contributors (thanks y'all!):
     Padraic Renaghan <padraic@renaghan.com>
     rayg <rayg@varchars.com>
     Robert Graff <rgraff@workingdemo.com>
+    Tatsuhiko Miyagawa <miyagawa@livedoor.jp>
     Tony Bowden <tony@kasei.com>
 
 =head1 COPYRIGHT AND LICENSE
